@@ -1,5 +1,7 @@
+# kate: default-dictionary en_US
+
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2019, Marek Gagolewski and other contributors.
+## Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -17,7 +19,7 @@
 ## this software without specific prior written permission.
 ##
 ## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
+## 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 ## BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 ## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 ## HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
@@ -33,16 +35,18 @@
 #' Passing Arguments to Functions in \pkg{stringi}
 #'
 #' @description
-#' Below we explain how \pkg{stringi} deals (in most of the cases)
-#' with its functions' arguments.
+#' Below we explain how \pkg{stringi} deals with its functions' arguments.
+#'
+#' If some function violates one of the following rules
+#' (for a very important reason),
+#' this is clearly indicated in its documentation (with discussion).
 #'
 #' @section Coercion of Arguments:
 #'
 #' When a character vector argument is expected, factors and other vectors
-#' coercible to characters vectors
-#' are silently converted with \code{\link{as.character}},
-#' otherwise an error is generated.
-#' Coercion from a list of non-atomic vectors each of length 1
+#' coercible to characters vectors are silently converted with
+#' \code{\link{as.character}}, otherwise an error is generated.
+#' Coercion from a list which does not consist of length-1 atomic vectors
 #' issues a warning.
 #'
 #' When a logical, numeric, or integer vector argument is expected,
@@ -59,12 +63,10 @@
 #' for instance, search for one pattern in each given string,
 #' search for each pattern in one given string,
 #' and search for the i-th pattern within the i-th string.
-#' This behaviod sometimes leads to peculiar results - we assume you know what
-#' you are doing.
 #'
 #' We of course took great care of performance issues:
 #' e.g., in regular expression searching, regex matchers are reused
-#' from iteration to iteration, as long it is possible.
+#' from iteration to iteration, as long as it is possible.
 #'
 #' Functions with some non-vectorized arguments are rare:
 #' e.g., regular expression matcher's settings are established
@@ -86,16 +88,19 @@
 #' For any vectorized operation, if at least one vector element is missing,
 #' then the corresponding resulting value is also set to \code{NA}.
 #'
-#' @section Preserving Input Objects' Attributes:
+#'
+#' @section Preserving Object Attributes:
 #'
 #' Generally, all our functions drop input objects' attributes
 #' (e.g., \code{\link{names}}, \code{\link{dim}}, etc.).
-#' This is generally because of advanced vectorization and for efficiency reasons.
-#' Thus, if arguments' preserving is needed,
-#' please remember to copy important attributes manually
-#' or use, e.g., the subsetting operation like \code{x[] <- stri_...(x, ...)}.
+#' This is due to deep vectorization as well as for efficiency reasons.
+#' If the preservation of attributes is needed,
+#' important attributes can be manually copied. Alternatively, the notation
+#' \code{x[] <- stri_...(x, ...)} can sometimes be used too.
 #'
-#' @name stringi-arguments
+#' @rdname about_arguments
+#' @name about_arguments
+#' @aliases arguments stringi-arguments stringi-arguments
 #' @family stringi_general_topics
 #' @family prepare_arg
 invisible(NULL)
@@ -120,8 +125,9 @@ invisible(NULL)
 # Otherwise the function throws an error.
 #
 # @family prepare_arg
-stri_prepare_arg_string <- function(x) {
-   .Call(C_stri_prepare_arg_string, x, NULL)
+stri_prepare_arg_string <- function(x)
+{
+    .Call(C_stri_prepare_arg_string, x, deparse(substitute(x)))
 }
 
 
@@ -132,6 +138,7 @@ stri_prepare_arg_string <- function(x) {
 # This is an internal function. However, the interested user may play with it
 # in order to get more insight on how \pkg{stringi} deals with its
 # functions' arguments. See `Value' section for details.
+# TODO: factors_as_strings
 #
 # @param x argument to be checked
 #
@@ -145,8 +152,9 @@ stri_prepare_arg_string <- function(x) {
 # Otherwise the function throws an error.
 #
 # @family prepare_arg
-stri_prepare_arg_double <- function(x) {
-   .Call(C_stri_prepare_arg_double, x, NULL)
+stri_prepare_arg_double <- function(x)
+{
+    .Call(C_stri_prepare_arg_double, x, deparse(substitute(x)))
 }
 
 
@@ -157,6 +165,7 @@ stri_prepare_arg_double <- function(x) {
 # This is an internal function. However, the interested user may play with it
 # in order to get more insight on how \pkg{stringi} deals with its
 # functions' arguments. See `Value' section for details.
+# TODO: factors_as_strings
 #
 # @param x argument to be checked
 #
@@ -170,8 +179,9 @@ stri_prepare_arg_double <- function(x) {
 # Otherwise the function throws an error.
 #
 # @family prepare_arg
-stri_prepare_arg_integer <- function(x) {
-   .Call(C_stri_prepare_arg_integer, x, NULL)
+stri_prepare_arg_integer <- function(x)
+{
+    .Call(C_stri_prepare_arg_integer, x, deparse(substitute(x)))
 }
 
 
@@ -182,6 +192,7 @@ stri_prepare_arg_integer <- function(x) {
 # This is an internal function. However, the interested user may play with it
 # in order to get more insight on how \pkg{stringi} deals with its
 # functions' arguments. See `Value' section for details.
+# TODO: factors_as_strings
 #
 # @param x argument to be checked
 #
@@ -195,8 +206,9 @@ stri_prepare_arg_integer <- function(x) {
 # Otherwise the function throws an error.
 #
 # @family prepare_arg
-stri_prepare_arg_logical <- function(x) {
-   .Call(C_stri_prepare_arg_logical, x, NULL)
+stri_prepare_arg_logical <- function(x)
+{
+    .Call(C_stri_prepare_arg_logical, x, deparse(substitute(x)))
 }
 
 
@@ -207,6 +219,7 @@ stri_prepare_arg_logical <- function(x) {
 # This is an internal function. However, the interested user may play with it
 # in order to get more insight on how \pkg{stringi} deals with its
 # functions' arguments. See `Value' section for details.
+# TODO: factors_as_strings
 #
 # @param x argument to be checked
 #
@@ -220,8 +233,9 @@ stri_prepare_arg_logical <- function(x) {
 # Otherwise the function throws an error.
 #
 # @family prepare_arg
-stri_prepare_arg_raw <- function(x) {
-   .Call(C_stri_prepare_arg_raw, x, NULL)
+stri_prepare_arg_raw <- function(x)
+{
+    .Call(C_stri_prepare_arg_raw, x, deparse(substitute(x)))
 }
 
 
@@ -241,8 +255,9 @@ stri_prepare_arg_raw <- function(x) {
 # A vector with one element (the first in \code{x}) is returned.
 #
 # @family prepare_arg
-stri_prepare_arg_string_1 <- function(x) {
-   .Call(C_stri_prepare_arg_string_1, x, NULL)
+stri_prepare_arg_string_1 <- function(x)
+{
+    .Call(C_stri_prepare_arg_string_1, x, deparse(substitute(x)))
 }
 
 
@@ -253,6 +268,7 @@ stri_prepare_arg_string_1 <- function(x) {
 # This is an internal function. However, the interested user may play with it
 # in order to get more insight on how \pkg{stringi} deals with its
 # functions' arguments. See `Value' section for details.
+# TODO: factors_as_strings
 #
 # @param x argument to be checked
 # @return
@@ -262,8 +278,9 @@ stri_prepare_arg_string_1 <- function(x) {
 # A vector with one element (the first in \code{x}) is returned.
 #
 # @family prepare_arg
-stri_prepare_arg_double_1 <- function(x) {
-   .Call(C_stri_prepare_arg_double_1, x, NULL)
+stri_prepare_arg_double_1 <- function(x)
+{
+    .Call(C_stri_prepare_arg_double_1, x, deparse(substitute(x)))
 }
 
 
@@ -275,16 +292,19 @@ stri_prepare_arg_double_1 <- function(x) {
 # in order to get more insight on how \pkg{stringi} deals with its
 # functions' arguments. See `Value' section for details.
 #
+# TODO: factors_as_strings
+#
 # @param x argument to be checked
 # @return
 # In the first place, \code{\link{stri_prepare_arg_integer}} is called.
-# On ab empty vector, an error is generated.
+# On an empty vector, an error is generated.
 # If there are more than 1 elements, a warning is generated.
 # A vector with one element (the first in \code{x}) is returned.
 #
 # @family prepare_arg
-stri_prepare_arg_integer_1 <- function(x) {
-   .Call(C_stri_prepare_arg_integer_1, x, NULL)
+stri_prepare_arg_integer_1 <- function(x)
+{
+    .Call(C_stri_prepare_arg_integer_1, x, deparse(substitute(x)))
 }
 
 
@@ -304,6 +324,7 @@ stri_prepare_arg_integer_1 <- function(x) {
 # A vector with one element (the first in \code{x}) is returned.
 #
 # @family prepare_arg
-stri_prepare_arg_logical_1 <- function(x) {
-   .Call(C_stri_prepare_arg_logical_1, x, NULL)
+stri_prepare_arg_logical_1 <- function(x)
+{
+    .Call(C_stri_prepare_arg_logical_1, x, deparse(substitute(x)))
 }
