@@ -1,5 +1,7 @@
+# kate: default-dictionary en_US
+
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2019, Marek Gagolewski and other contributors.
+## Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -17,7 +19,7 @@
 ## this software without specific prior written permission.
 ##
 ## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
+## 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 ## BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 ## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 ## HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
@@ -30,7 +32,7 @@
 
 
 #' @title
-#' Count the Number of Pattern Matches
+#' Count the Number of Pattern Occurrences
 #'
 #' @description
 #' These functions count the number of occurrences
@@ -66,78 +68,85 @@
 #' @return All the functions return an integer vector.
 #'
 #' @examples
-#' s <- "Lorem ipsum dolor sit amet, consectetur adipisicing elit."
-#' stri_count(s, fixed="dolor")
-#' stri_count(s, regex="\\p{L}+")
+#' s <- 'Lorem ipsum dolor sit amet, consectetur adipisicing elit.'
+#' stri_count(s, fixed='dolor')
+#' stri_count(s, regex='\\p{L}+')
 #'
-#' stri_count_fixed(s, " ")
-#' stri_count_fixed(s, "o")
-#' stri_count_fixed(s, "it")
+#' stri_count_fixed(s, ' ')
+#' stri_count_fixed(s, 'o')
+#' stri_count_fixed(s, 'it')
 #' stri_count_fixed(s, letters)
-#' stri_count_fixed("babab", "b")
-#' stri_count_fixed(c("stringi", "123"), "string")
+#' stri_count_fixed('babab', 'b')
+#' stri_count_fixed(c('stringi', '123'), 'string')
 #'
-#' stri_count_charclass(c("stRRRingi", "STrrrINGI", "123"),
-#'    c("\\p{Ll}", "\\p{Lu}", "\\p{Zs}"))
-#' stri_count_charclass(" \t\n", "\\p{WHITE_SPACE}") # white space - binary property
-#' stri_count_charclass(" \t\n", "\\p{Z}") # white-space - general category (note the difference)
+#' stri_count_charclass(c('stRRRingi', 'STrrrINGI', '123'),
+#'    c('\\p{Ll}', '\\p{Lu}', '\\p{Zs}'))
+#' stri_count_charclass(' \t\n', '\\p{WHITE_SPACE}') # white space - binary property
+#' stri_count_charclass(' \t\n', '\\p{Z}') # white-space - general category (note the difference)
 #'
-#' stri_count_regex(s, "(s|el)it")
-#' stri_count_regex(s, "i.i")
-#' stri_count_regex(s, ".it")
-#' stri_count_regex("bab baab baaab", c("b.*?b", "b.b"))
-#' stri_count_regex(c("stringi", "123"), "^(s|1)")
+#' stri_count_regex(s, '(s|el)it')
+#' stri_count_regex(s, 'i.i')
+#' stri_count_regex(s, '.it')
+#' stri_count_regex('bab baab baaab', c('b.*?b', 'b.b'))
+#' stri_count_regex(c('stringi', '123'), '^(s|1)')
 #'
 #' @family search_count
 #' @export
 #' @rdname stri_count
-stri_count <- function(str, ..., regex, fixed, coll, charclass) {
-   providedarg <- c("regex"=!missing(regex), "fixed"    =!missing(fixed),
-                    "coll" =!missing(coll),  "charclass"=!missing(charclass))
+stri_count <- function(str, ..., regex, fixed, coll, charclass)
+{
+    providedarg <- c(
+        regex = !missing(regex),
+        fixed = !missing(fixed),
+        coll = !missing(coll),
+        charclass = !missing(charclass))
 
-   if (sum(providedarg) != 1)
-      stop("you have to specify either `regex`, `fixed`, `coll`, or `charclass`")
+    if (sum(providedarg) != 1)
+        stop("you have to specify either `regex`, `fixed`, `coll`, or `charclass`")
 
-   if (providedarg["regex"])
-      stri_count_regex(str, regex, ...)
-   else if (providedarg["fixed"])
-      stri_count_fixed(str, fixed, ...)
-   else if (providedarg["coll"])
-      stri_count_coll(str, coll, ...)
-   else if (providedarg["charclass"])
-      stri_count_charclass(str, charclass, ...)
+    if (providedarg["regex"])
+        stri_count_regex(str, regex, ...)
+    else if (providedarg["fixed"])
+        stri_count_fixed(str, fixed, ...)
+    else if (providedarg["coll"])
+        stri_count_coll(str, coll, ...)
+    else if (providedarg["charclass"])
+        stri_count_charclass(str, charclass, ...)
 }
 
 
 #' @export
 #' @rdname stri_count
 stri_count_charclass <- function(str, pattern) {
-   .Call(C_stri_count_charclass, str, pattern)
+    .Call(C_stri_count_charclass, str, pattern)
 }
 
 
 #' @export
 #' @rdname stri_count
-stri_count_coll <- function(str, pattern, ..., opts_collator=NULL) {
-   if (!missing(...))
-       opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
-   .Call(C_stri_count_coll, str, pattern, opts_collator)
+stri_count_coll <- function(str, pattern, ..., opts_collator = NULL)
+{
+    if (!missing(...))
+        opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
+    .Call(C_stri_count_coll, str, pattern, opts_collator)
 }
 
 
 #' @export
 #' @rdname stri_count
-stri_count_fixed <- function(str, pattern, ..., opts_fixed=NULL) {
-   if (!missing(...))
-       opts_fixed <- do.call(stri_opts_fixed, as.list(c(opts_fixed, ...)))
-   .Call(C_stri_count_fixed, str, pattern, opts_fixed)
+stri_count_fixed <- function(str, pattern, ..., opts_fixed = NULL)
+{
+    if (!missing(...))
+        opts_fixed <- do.call(stri_opts_fixed, as.list(c(opts_fixed, ...)))
+    .Call(C_stri_count_fixed, str, pattern, opts_fixed)
 }
 
 
 #' @export
 #' @rdname stri_count
-stri_count_regex <- function(str, pattern, ..., opts_regex=NULL) {
-   if (!missing(...))
-       opts_regex <- do.call(stri_opts_regex, as.list(c(opts_regex, ...)))
-   .Call(C_stri_count_regex, str, pattern, opts_regex)
+stri_count_regex <- function(str, pattern, ..., opts_regex = NULL)
+{
+    if (!missing(...))
+        opts_regex <- do.call(stri_opts_regex, as.list(c(opts_regex, ...)))
+    .Call(C_stri_count_regex, str, pattern, opts_regex)
 }
