@@ -1,5 +1,7 @@
+# kate: default-dictionary en_US
+
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2017, Marek Gagolewski and other contributors.
+## Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -17,7 +19,7 @@
 ## this software without specific prior written permission.
 ##
 ## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
+## 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 ## BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 ## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 ## HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
@@ -29,8 +31,7 @@
 ## EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
-invisible(NULL) # TO BE DONE, version >= 0.3
-
+invisible(NULL)  # TO DO
 
 # #' @title
 # #' t.b.d.
@@ -44,7 +45,7 @@ invisible(NULL) # TO BE DONE, version >= 0.3
 # #' @param x numeric vector
 # #' @param ruleset single string; one of \code{spellout}, \code{ordinal}, \code{duration},
 # #'                 \code{numbering_system}?
-# #' @param locale \code{NULL} or \code{""} for case mapping following
+# #' @param locale \code{NULL} or \code{''} for case mapping following
 # #' the conventions of the default locale, or a single string with
 # #' locale identifier, see \link{stringi-locale}.
 # #'
@@ -71,7 +72,7 @@ invisible(NULL) # TO BE DONE, version >= 0.3
 # #' @param str character vector
 # #' @param ruleset single string; one of \code{spellout}, \code{ordinal}, \code{duration},
 # #'                 \code{numbering_system}?
-# #' @param locale \code{NULL} or \code{""} for case mapping following
+# #' @param locale \code{NULL} or \code{''} for case mapping following
 # #' the conventions of the default locale, or a single string with
 # #' locale identifier, see \link{stringi-locale}.
 # #' @param lenient single logical value; ....
