@@ -1,7 +1,7 @@
 # kate: default-dictionary en_US
 
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2020, Marek Gagolewski <https://www.gagolewski.com>
+## Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -70,34 +70,57 @@
 #' (1) separate input base characters and accents, and then (2)
 #' convert uppercase to lowercase.
 #' To achieve this, a compound transform can be specified as follows:
-#' \code{NFKD; Lower; Latin-Katakana;}
+#' \code{NFKD; Lower; Latin-Katakana;} (with the default \code{rules=FALSE}).
+#'
+#' Custom rule-based transliteration is also supported, see the \pkg{ICU}
+#' manual and below for some examples.
 #'
 #' @param str character vector
 #' @param id a single string with transform identifier,
-#' see \code{\link{stri_trans_list}}
+#'     see \code{\link{stri_trans_list}}, or custom transliteration rules
+#' @param rules if \code{TRUE}, treat \code{id} as a string with
+#'     semicolon-separated transliteration rules (see the \pkg{ICU} manual);
+#' @param forward transliteration direction (\code{TRUE} for forward,
+#'     \code{FALSE} for reverse)
+#'
 #' @return
 #' Returns a character vector.
 #'
-#' @references
-#' \emph{General Transforms} -- ICU User Guide,
-#' \url{http://userguide.icu-project.org/transforms/general}
-#'
-#' @family transform
-#' @export
-#'
 #' @examples
 #' stri_trans_general('gro\u00df', 'latin-ascii')
 #' stri_trans_general('stringi', 'latin-greek')
 #' stri_trans_general('stringi', 'latin-cyrillic')
 #' stri_trans_general('stringi', 'upper') # see stri_trans_toupper
 #' stri_trans_general('\u0104', 'nfd; lower') # compound id; see stri_trans_nfd
-#' stri_trans_general('tato nie wraca ranki wieczory', 'pl-pl_FONIPA')
+#' stri_trans_general('Marek G\u0105golewski', 'pl-pl_FONIPA')
 #' stri_trans_general('\u2620', 'any-name') # character name
 #' stri_trans_general('\\N{latin small letter a}', 'name-any') # decode name
-#' stri_trans_general('\u2620', 'hex') # to hex
-stri_trans_general <- function(str, id)
+#' stri_trans_general('\u2620', 'hex/c') # to hex
+#'
+#' x <- "\uC885\uB85C\uAD6C \uC0AC\uC9C1\uB3D9"
+#' stringi::stri_trans_general(x, "Hangul-Latin")
+#' # Deviate from the ICU rules of romanisation of Korean,
+#' # see https://en.wikipedia.org/wiki/Romanization_of_Korean
+#' id <- "
+#'     :: NFD;
+#'     \u11A8 > k;
+#'     \u11AE > t;
+#'     \u11B8 > p;
+#'     \u1105 > r;
+#'     :: Hangul-Latin;
+#' "
+#' stringi::stri_trans_general(x, id, rules=TRUE)
+#'
+#'
+#' @references
+#' \emph{General Transforms} -- ICU User Guide,
+#' \url{https://unicode-org.github.io/icu/userguide/transforms/general/}
+#'
+#' @family transform
+#' @export
+stri_trans_general <- function(str, id, rules=FALSE, forward=TRUE)
 {
-    .Call(C_stri_trans_general, str, id)
+    .Call(C_stri_trans_general, str, id, rules, forward)
 }
 
 
@@ -113,11 +136,16 @@ stri_trans_general <- function(str, id)
 #'
 #' @references
 #' \emph{General Transforms} -- ICU User Guide,
-#' \url{http://userguide.icu-project.org/transforms/general}
+#' \url{https://unicode-org.github.io/icu/userguide/transforms/general/}
+#'
+#' @examples
+#' stri_trans_list()
 #'
 #' @family transform
 #' @export
 stri_trans_list <- function()
 {
-    .Call(C_stri_trans_list)
+    stri_sort(
+        .Call(C_stri_trans_list), locale="en_US", numeric=TRUE, strength=1
+    )
 }
