@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2020, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -61,11 +61,14 @@ using namespace std;
  *
  * @version 0.3-1 (Marek Gagolewski, 2014-11-04)
  *    Issue #112: str_prepare_arg* retvals were not PROTECTed from gc
+ *
+ * @version 1.7.1 (Marek Gagolewski, 2021-06-29)
+ *     get_length
  */
-SEXP stri__locate_firstlast_coll(SEXP str, SEXP pattern, SEXP opts_collator, bool first)
+SEXP stri__locate_firstlast_coll(SEXP str, SEXP pattern, SEXP opts_collator, bool first, bool get_length1)
 {
-    PROTECT(str = stri_prepare_arg_string(str, "str"));
-    PROTECT(pattern = stri_prepare_arg_string(pattern, "pattern"));
+    PROTECT(str = stri__prepare_arg_string(str, "str"));
+    PROTECT(pattern = stri__prepare_arg_string(pattern, "pattern"));
 
     UCollator* collator = NULL;
     collator = stri__ucol_open(opts_collator);
@@ -77,7 +80,7 @@ SEXP stri__locate_firstlast_coll(SEXP str, SEXP pattern, SEXP opts_collator, boo
 
     SEXP ret;
     STRI__PROTECT(ret = Rf_allocMatrix(INTSXP, vectorize_length, 2));
-    stri__locate_set_dimnames_matrix(ret);
+    stri__locate_set_dimnames_matrix(ret, get_length1);
     int* ret_tab = INTEGER(ret);
 
     for (R_len_t i = pattern_cont.vectorize_init();
@@ -86,8 +89,11 @@ SEXP stri__locate_firstlast_coll(SEXP str, SEXP pattern, SEXP opts_collator, boo
     {
         ret_tab[i]                  = NA_INTEGER;
         ret_tab[i+vectorize_length] = NA_INTEGER;
-        STRI__CONTINUE_ON_EMPTY_OR_NA_STR_PATTERN(str_cont, pattern_cont,
-                ;/*nothing*/, ;/*nothing*/)
+        STRI__CONTINUE_ON_EMPTY_OR_NA_STR_PATTERN(
+            str_cont, pattern_cont,
+            ;/*nothing on NA - keep NA_INTEGER*/,
+            { if (get_length1) ret_tab[i] = ret_tab[i+vectorize_length] = -1; }
+        )
 
         UStringSearch *matcher = pattern_cont.getMatcher(i, str_cont.get(i));
         usearch_reset(matcher);
@@ -101,8 +107,8 @@ SEXP stri__locate_firstlast_coll(SEXP str, SEXP pattern, SEXP opts_collator, boo
         }
         STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
 
-        // if we have match (otherwise don't do anything)
-        if (start != USEARCH_DONE) {
+
+        if (start != USEARCH_DONE) {  // there is a match
             ret_tab[i]                  = start;
             ret_tab[i+vectorize_length] = start + usearch_getMatchedLength(matcher);
 
@@ -112,7 +118,14 @@ SEXP stri__locate_firstlast_coll(SEXP str, SEXP pattern, SEXP opts_collator, boo
                                               1, // 0-based index -> 1-based
                                               0  // end returns position of next character after match
                                              );
+
+            if (get_length1) ret_tab[i+vectorize_length] -= ret_tab[i] - 1;  // to->length
         }
+        else if (get_length1) {
+            // not found
+            ret_tab[i+vectorize_length] = ret_tab[i] = -1;
+        }
+        // else NA_INTEGER already
     }
 
     if (collator) {
@@ -145,10 +158,14 @@ SEXP stri__locate_firstlast_coll(SEXP str, SEXP pattern, SEXP opts_collator, boo
  *
  * @version 0.2-3 (Marek Gagolewski, 2014-05-08)
  *          new fun: stri_locate_first_coll (opts_collator == NA not allowed)
+ *
+ * @version 1.7.1 (Marek Gagolewski, 2021-06-29)
+ *     get_length
  */
-SEXP stri_locate_first_coll(SEXP str, SEXP pattern, SEXP opts_collator)
+SEXP stri_locate_first_coll(SEXP str, SEXP pattern, SEXP opts_collator, SEXP get_length)
 {
-    return stri__locate_firstlast_coll(str, pattern, opts_collator, true);
+    bool get_length1 = stri__prepare_arg_logical_1_notNA(get_length, "get_length");
+    return stri__locate_firstlast_coll(str, pattern, opts_collator, true, get_length1);
 }
 
 
@@ -170,10 +187,14 @@ SEXP stri_locate_first_coll(SEXP str, SEXP pattern, SEXP opts_collator)
  *
  * @version 0.2-3 (Marek Gagolewski, 2014-05-08)
  *          new fun: stri_locate_last_coll (opts_collator == NA not allowed)
+ *
+ * @version 1.7.1 (Marek Gagolewski, 2021-06-29)
+ *     get_length
  */
-SEXP stri_locate_last_coll(SEXP str, SEXP pattern, SEXP opts_collator)
+SEXP stri_locate_last_coll(SEXP str, SEXP pattern, SEXP opts_collator, SEXP get_length)
 {
-    return stri__locate_firstlast_coll(str, pattern, opts_collator, false);
+    bool get_length1 = stri__prepare_arg_logical_1_notNA(get_length, "get_length");
+    return stri__locate_firstlast_coll(str, pattern, opts_collator, false, get_length1);
 }
 
 
@@ -203,12 +224,16 @@ SEXP stri_locate_last_coll(SEXP str, SEXP pattern, SEXP opts_collator)
  *
  * @version 0.4-1 (Marek Gagolewski, 2014-11-27)
  *    FR #117: omit_no_match arg added
+ *
+ * @version 1.7.1 (Marek Gagolewski, 2021-06-29)
+ *     get_length
  */
-SEXP stri_locate_all_coll(SEXP str, SEXP pattern, SEXP omit_no_match, SEXP opts_collator)
+SEXP stri_locate_all_coll(SEXP str, SEXP pattern, SEXP omit_no_match, SEXP opts_collator, SEXP get_length)
 {
     bool omit_no_match1 = stri__prepare_arg_logical_1_notNA(omit_no_match, "omit_no_match");
-    PROTECT(str = stri_prepare_arg_string(str, "str"));
-    PROTECT(pattern = stri_prepare_arg_string(pattern, "pattern"));
+    bool get_length1 = stri__prepare_arg_logical_1_notNA(get_length, "get_length");
+    PROTECT(str = stri__prepare_arg_string(str, "str"));
+    PROTECT(pattern = stri__prepare_arg_string(pattern, "pattern"));
 
     UCollator* collator = NULL;
     collator = stri__ucol_open(opts_collator);
@@ -227,7 +252,7 @@ SEXP stri_locate_all_coll(SEXP str, SEXP pattern, SEXP omit_no_match, SEXP opts_
     {
         STRI__CONTINUE_ON_EMPTY_OR_NA_STR_PATTERN(str_cont, pattern_cont,
                 SET_VECTOR_ELT(ret, i, stri__matrix_NA_INTEGER(1, 2));,
-                SET_VECTOR_ELT(ret, i, stri__matrix_NA_INTEGER(omit_no_match1?0:1, 2));)
+                SET_VECTOR_ELT(ret, i, stri__matrix_NA_INTEGER(omit_no_match1?0:1, 2, get_length1?-1:NA_INTEGER));)
 
         UStringSearch *matcher = pattern_cont.getMatcher(i, str_cont.get(i));
         usearch_reset(matcher);
@@ -237,7 +262,7 @@ SEXP stri_locate_all_coll(SEXP str, SEXP pattern, SEXP omit_no_match, SEXP opts_
         STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
 
         if (start == USEARCH_DONE) {
-            SET_VECTOR_ELT(ret, i, stri__matrix_NA_INTEGER(omit_no_match1?0:1, 2));
+            SET_VECTOR_ELT(ret, i, stri__matrix_NA_INTEGER(omit_no_match1?0:1, 2, get_length1?-1:NA_INTEGER));
             continue;
         }
 
@@ -255,7 +280,7 @@ SEXP stri_locate_all_coll(SEXP str, SEXP pattern, SEXP omit_no_match, SEXP opts_
         deque< pair<R_len_t, R_len_t> >::iterator iter = occurrences.begin();
         for (R_len_t j = 0; iter != occurrences.end(); ++iter, ++j) {
             pair<R_len_t, R_len_t> match = *iter;
-            ans_tab[j]             = match.first;
+            ans_tab[j]              = match.first;
             ans_tab[j+noccurrences] = match.second;
         }
 
@@ -265,11 +290,17 @@ SEXP stri_locate_all_coll(SEXP str, SEXP pattern, SEXP omit_no_match, SEXP opts_
                                           1, // 0-based index -> 1-based
                                           0  // end returns position of next character after match
                                          );
+
+        if (get_length1) {
+            for (R_len_t j=0; j < noccurrences; ++j)
+                ans_tab[j+noccurrences] -= ans_tab[j] - 1;  // to->length
+        }
+
         SET_VECTOR_ELT(ret, i, ans);
         STRI__UNPROTECT(1);
     }
 
-    stri__locate_set_dimnames_list(ret);
+    stri__locate_set_dimnames_list(ret, get_length1);
     if (collator) {
         ucol_close(collator);
         collator=NULL;
